@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ class TkgdqClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeEntity", params)
+            headers = request.headers
+            body = self.call("DescribeEntity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeEntityResponse()
@@ -64,7 +65,8 @@ class TkgdqClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRelation", params)
+            headers = request.headers
+            body = self.call("DescribeRelation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRelationResponse()
@@ -92,7 +94,8 @@ class TkgdqClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTriple", params)
+            headers = request.headers
+            body = self.call("DescribeTriple", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTripleResponse()
